@@ -500,6 +500,7 @@ class Hardware(BaseHardware):
     QS.pc_to_hermes(self.pc2hermes)
   def SetVNA(self, key_down=None, vna_start=None, vna_stop=None, vna_count=None, do_tx=False):
     if vna_count is not None:	# must be called first
+      if DEBUG: print("vna_count", vna_count)
       self.vna_count = vna_count
     if vna_start is None:
       start = 0
@@ -534,9 +535,12 @@ class Hardware(BaseHardware):
       if not self.vna_started:
         self.vna_started = True
         self.SetControlByte(9, 2, 0x80)		# turn on VNA mode
-      QS.set_PTT(1)
+        if DEBUG: print("vna_started TRUE")
+      QS.set_key_down(1)
+      if DEBUG: print ("vna key down")
     else:
-      QS.set_PTT(0)
+      QS.set_key_down(0)
+      if DEBUG: print ("vna key up")
     return start, stop	# Return actual frequencies after all phase rounding
   def ImmediateChange(self, name):
     if name == 'keyupDelay':
