@@ -393,7 +393,7 @@ class GraphScreen(wx.Window):
     f = float(x - self.x0) * sample_rate / self.data_width
     c = None
     y = originY + 1
-    for freq, color in conf.BandPlan:
+    for freq, color in application.BandPlan:
       freq -= VFO
       if f < freq:
         xend = int(self.x0 + float(freq) * self.data_width / sample_rate + 0.5)
@@ -883,6 +883,7 @@ class App(wx.App):
     else:
       setattr(conf, 'config_file_exists', False)
     # Read in configuration from the selected radio
+    self.BandPlan = []
     if configure: self.local_conf = configure.Configuration(self, argv_options.AskMe)
     if configure: self.local_conf.UpdateConf()
     # Choose whether to use Unicode or text symbols
