@@ -413,7 +413,7 @@ class QuiskText(wx.BoxSizer):
 class QuiskButtons:
   """Base class for special buttons."""
   def __init__(self, idName):
-    self.idName = idName
+    self.idName = idName	# idName can be ''
     self.up_brush = wx.Brush(conf.color_btn)
     r, g, b = self.up_brush.GetColour().Get(False)
     r, g, b = min(255,r+32), min(255,g+32), min(255,b+32)
